@@ -22,11 +22,11 @@ A Newbie Friendly Module to Create, Train, Validate and Test Perceptrons / Neuro
 
 =head1 VERSION
 
-Version 1.03
+Version 1.04
 
 =cut
 
-our $VERSION = '1.03';
+our $VERSION = '1.04';
 
 # default values
 use constant LEARNING_RATE => 0.05;
@@ -41,35 +41,35 @@ use constant TUNE_DOWN => 0;
     use AI::Perceptron::Simple qw(...);
 
     # create a new nerve / neuron / perceptron
-    $perceptron = AI::Perceptron::Simple->new( {
-        initial_value => $any_value_that_makes_sense, # size of each dendrite :)
+    $nerve = AI::Perceptron::Simple->new( {
+        initial_value => $size_of_each_dendrite,
         learning_rate => 0.3, # optional
         threshold => 0.85, # optional
-        attribs => \@attributes, # dendrites
+        attribs => \@dendrites,
     } );
 
     # train
-    $perceptron->tame( ... );
-    $perceptron->exercise( ... );
-    $perceptron->train( $training_data_csv, $expected_column_name, $save_nerve_to );
+    $nerve->tame( ... );
+    $nerve->exercise( ... );
+    $nerve->train( $training_data_csv, $expected_column_name, $save_nerve_to );
     # or
-    $perceptron->train(
+    $nerve->train(
         $training_data_csv, $expected_column_name, $save_nerve_to, 
         $show_progress, $identifier); # these two parameters must go together
 
 
     # validate
-    $perceptron->take_lab_test( ... );
-    $perceptron->take_mock_exam( ... );
+    $nerve->take_lab_test( ... );
+    $nerve->take_mock_exam( ... );
 
     # fill results to original file
-    $perceptron->validate( { 
+    $nerve->validate( { 
         stimuli_validate => $validation_data_csv, 
         predicted_column_index => 4,
      } );
     # or        
     # fill results to a new file
-    $perceptron->validate( {
+    $nerve->validate( {
         stimuli_validate => $validation_data_csv,
         predicted_column_index => 4,
         results_write_to => $new_csv
@@ -77,13 +77,13 @@ use constant TUNE_DOWN => 0;
 
 
     # test - see "validate" method, same usage
-    $perceptron->take_real_exam( ... );
-    $perceptron->work_in_real_world( ... );
-    $perceptron->test( ... );
+    $nerve->take_real_exam( ... );
+    $nerve->work_in_real_world( ... );
+    $nerve->test( ... );
 
 
     # confusion matrix
-    my %c_matrix = $perceptron->get_confusion_matrix( { 
+    my %c_matrix = $nerve->get_confusion_matrix( { 
         full_data_file => $file_csv, 
         actual_output_header => $header_name,
         predicted_output_header => $predicted_header_name,
@@ -98,7 +98,7 @@ use constant TUNE_DOWN => 0;
     }
 
     # output to console
-    $perceptron->display_confusion_matrix( \%c_matrix, { 
+    $nerve->display_confusion_matrix( \%c_matrix, { 
         zero_as => "bad apples", # cat  milk   green  etc.
         one_as => "good apples", # dog  honey  pink   etc.
     } );
@@ -110,7 +110,7 @@ use constant TUNE_DOWN => 0;
 
     my $nerve_file = "apples.nerve";
     preserve( ... );
-    save_perceptron( $perceptron, $nerve_file );
+    save_perceptron( $nerve, $nerve_file );
 
     # load data of percpetron for use in actual program
     my $apple_nerve = revive( ... );
@@ -122,7 +122,7 @@ use constant TUNE_DOWN => 0;
 
     my $yaml_nerve_file = "pearls.yaml";
     preserve_as_yaml ( ... );
-    save_perceptron_yaml ( $perceptron, $yaml_nerve_file );
+    save_perceptron_yaml ( $nerve, $yaml_nerve_file );
 
     # load nerve data on the other computer
     my $pearl_nerve = revive_from_yaml ( ... );
@@ -246,7 +246,7 @@ sub shuffle_data {
 
         csv( in => \@aoa, out => $_, encoding => ":encoding(utf-8)" ) 
         and
-        print "Saved shuffled data into ", basename($_), "!\n";;
+        print "Saved shuffled data into ", basename($_), "!\n";
 
     }
 }
@@ -437,7 +437,7 @@ sub train {
     
     # CSV processing is all according to the documentation of Text::CSV
     open my $data_fh, "<:encoding(UTF-8)", $stimuli_train_csv 
-        or die "Can't open $stimuli_train_csv: $!";
+        or croak "Can't open $stimuli_train_csv: $!";
     
     my $csv = Text::CSV->new( {auto_diag => 1, binary => 1} );
     
@@ -753,7 +753,7 @@ sub _fill_predicted_values {
 
     # CSV processing is all according to the documentation of Text::CSV
     open my $data_fh, "<:encoding(UTF-8)", $stimuli_validate 
-        or die "Can't open $stimuli_validate: $!";
+        or croak "Can't open $stimuli_validate: $!";
     
     my $csv = Text::CSV->new( {auto_diag => 1, binary => 1} );
     
@@ -866,7 +866,7 @@ sub _collect_stats {
     
     # CSV processing is all according to the documentation of Text::CSV
     open my $data_fh, "<:encoding(UTF-8)", $file
-        or die "Can't open $file: $!";
+        or croak "Can't open $file: $!";
     
     my $csv = Text::CSV->new( {auto_diag => 1, binary => 1} );
     
@@ -1130,7 +1130,7 @@ Display the confusion matrix. If C<%confusion_matrix> has C<more_stats> elements
 
 C<%confusion_matrix> is the same confusion matrix returned by the C<get_confusion_matrix> method.
 
-For C<%labels>, since C<0>'s and C<1>'s won't make much sense as the output in most cases, therefore, the following keys must be specified:
+For C<%labels>, since C<0>'s and C<1>'s won't make much sense as the output labels in most cases, therefore, the following keys must be specified:
 
 =over 4
 
@@ -1254,7 +1254,7 @@ See C<PERCEPTRON DATA> and C<KNOWN ISSUES> sections for more details on the subr
 
 The parameters and usage are the same as C<save_perceptron>. See the next subroutine.
 
-=head2 save_perceptron ( $nerve_file )
+=head2 save_perceptron ( $nerve, $nerve_file )
 
 Saves the C<AI::Perceptron::Simple> object into a C<Storable> file. There shouldn't be a need to call this method manually since after every training 
 process this will be called automatically.
@@ -1306,7 +1306,7 @@ The file type currently supported is YAML. Please be careful with the data as yo
 
 The parameters and usage are the same as C<save_perceptron_yaml>. See the next subroutine.
 
-=head2 save_perceptron_yaml ( $nerve_file )
+=head2 save_perceptron_yaml ( $nerve, $yaml_nerve_file )
 
 Saves the C<AI::Perceptron::Simple> object into a C<YAML> file.
 
@@ -1341,6 +1341,7 @@ sub revive_from_yaml {
 sub load_perceptron_yaml {
     my $nerve_file_to_load = shift;
     use YAML;
+    local $YAML::LoadBlessed = 1;
     my $loaded_nerve = YAML::LoadFile( $nerve_file_to_load );
     no YAML;
     
